@@ -8,7 +8,7 @@ from plottr.analyzer.fitters.fitter_base import Fit, FitResult
 
 class Cosine(Fit):
     @staticmethod
-    def model(coordinates: np.ndarray, # type: ignore[override]
+    def model(coordinates: np.ndarray,
               A: float, f: float, phi: float, of: float) -> np.ndarray:
         """$A \cos(2 \pi f x + \phi) + of$"""
         return A * np.cos(2 * np.pi * coordinates * f + phi) + of
@@ -34,7 +34,7 @@ class Cosine(Fit):
 
 class Exponential(Fit):
     @staticmethod
-    def model(coordinates: np.ndarray, a: float, b: float) -> np.ndarray: # type: ignore[override]
+    def model(coordinates: np.ndarray, a: float, b: float) -> np.ndarray:
         """ a * b ** x"""
         return a * b ** coordinates
 
