@@ -1,14 +1,14 @@
 import os
 from enum import Enum
-from typing import List, Any, Optional, Dict
+from typing import List, Any, Optional, Dict, Sequence, Union
 from pprint import pprint
 
 from plottr import QtCore, QtGui, QtWidgets, Slot, Signal
 from plottr.data.datadict import DataDict
 
 
-def findFilesByExtension(path: str, extensions: List[str]) -> Optional[Dict[str, Any]]:
-    ret = []
+def findFilesByExtension(path: str, extensions: Sequence[str]) -> List[str]:
+    ret: List[str] = []
     contents = os.listdir(path)
     for c in sorted(contents):
         abspath = os.path.abspath(os.path.join(path, c))
@@ -29,11 +29,11 @@ class DataFileContent(QtWidgets.QTreeWidget):
     #:   - name of the group within the currently selected file
     plotRequested = Signal(str)
 
-    def __init__(self, parent=None):
+    def __init__(self, parent: Optional[QtWidgets.QWidget] = None):
         super().__init__(parent)
 
-        self.data = {}
-        self.groupItems = []
+        self.data: Dict[str, DataDict] = {}
+        self.groupItems: List[QtWidgets.QTreeWidgetItem] = []
         self.selectedGroup = None
 
         self.dataPopup = QtWidgets.QMenu('Data actions', self)
@@ -42,7 +42,7 @@ class DataFileContent(QtWidgets.QTreeWidget):
 
 
     @Slot(object)
-    def setData(self, data: Dict[str, DataDict]):
+    def setData(self, data: Dict[str, DataDict]) -> None:
         """Set the data to display."""
         self.clear()
         self.data = {}
@@ -57,7 +57,10 @@ class DataFileContent(QtWidgets.QTreeWidget):
             metaParent = QtWidgets.QTreeWidgetItem(grpItem, ['[META]'])
 
             for dn, dv in grpData.data_items():
-                vals = [grpData.label(dn), str(grpData.meta_val('shape', dn))]
+                label = grpData.label(dn)
+                assert label is not None
+                vals = [label, str(grpData.meta_val('shape', dn))]
+
                 if dn in grpData.dependents():
                     vals.append(f'Data (depends on {str(tuple(grpData.axes(dn)))[1:]}')
                 else:
@@ -79,7 +82,7 @@ class DataFileContent(QtWidgets.QTreeWidget):
             self.resizeColumnToContents(i)
 
     @Slot(QtCore.QPoint)
-    def onCustomContextMenuRequested(self, pos):
+    def onCustomContextMenuRequested(self, pos: QtCore.QPoint) -> None:
         item = self.itemAt(pos)
         if item not in self.groupItems:
             return
@@ -89,7 +92,7 @@ class DataFileContent(QtWidgets.QTreeWidget):
         self.dataPopup.exec(self.mapToGlobal(pos))
 
     @Slot()
-    def onPlotActionTriggered(self):
+    def onPlotActionTriggered(self) -> None:
         self.plotRequested.emit(self.selectedGroup)
 
 
@@ -108,14 +111,14 @@ class DataFileList(QtWidgets.QTreeWidget):
     #: Signal(list) -- emitted when new files have been found
     newDataFilesFound = Signal(list)
 
-    def __init__(self, parent=None):
+    def __init__(self, parent: Optional[QtWidgets.QWidget] = None):
         super().__init__(parent)
 
-        self.files = []
-        self.path = None
+        self.files: List[str] = []
+        self.path: Optional[str] = None
 
     @staticmethod
-    def find(parent, name):
+    def finditem(parent: Union["DataFileList", QtWidgets.QTreeWidgetItem], name: str) -> Optional[QtWidgets.QTreeWidgetItem]:
         if isinstance(parent, DataFileList):
             existingItems = [parent.topLevelItem(i) for i in
                              range(parent.topLevelItemCount())]
@@ -125,37 +128,44 @@ class DataFileList(QtWidgets.QTreeWidget):
 
         item = None
         for item_ in existingItems:
-            if item_.text(0) == name:
-                item = item_
-                break
+            if item_ is not None:
+                if item_.text(0) == name:
+                    item = item_
+                    break
         return item
 
-    def itemPath(self, item):
-        def buildPath(i, suffix=''):
+    def itemPath(self, item: QtWidgets.QTreeWidgetItem) -> str:
+        def buildPath(i: Optional[QtWidgets.QTreeWidgetItem], suffix: str = '') -> str:
             if i is None:
                 return suffix
             newSuffix = i.text(0)
             if suffix != '':
                 newSuffix += os.path.sep+suffix
             return buildPath(i.parent(), suffix=newSuffix)
+        assert self.path is not None
         return os.path.join(self.path, buildPath(item))
 
-    def findItemByPath(self, path: str):
+    def findItemByPath(self, path: str) -> Optional[QtWidgets.QTreeWidgetItem]:
+        assert self.path is not None
         path = path[len(self.path) + len(os.path.sep):]
         pathList = path.split(os.path.sep)
-        parent = self
+        parent: Union["DataFileList", QtWidgets.QTreeWidgetItem] = self
         for p in pathList:
-            parent = self.find(parent, p)
-            if parent is None:
+            new_parent = self.finditem(parent, p)
+            if new_parent is None:
                 return None
+            else:
+                parent = new_parent
+        assert isinstance(parent, QtWidgets.QTreeWidgetItem)
         return parent
 
-    def addItemByPath(self, path: str):
+    def addItemByPath(self, path: str) -> None:
+        assert self.path is not None
         path = path[len(self.path)+len(os.path.sep):]
         pathList = path.split(os.path.sep)
 
-        def add(parent, name):
-            item = self.find(parent, name)
+        def add(parent: Union["DataFileList", QtWidgets.QTreeWidgetItem], name: str) -> Union["DataFileList", QtWidgets.QTreeWidgetItem]:
+            item = self.finditem(parent, name)
             if item is None:
                 item = QtWidgets.QTreeWidgetItem(parent, [name])
                 if os.path.splitext(name)[-1] in self.fileExtensions:
@@ -169,13 +179,13 @@ class DataFileList(QtWidgets.QTreeWidget):
                     parent.addChild(item)
             return item
 
-        parent = self
+        parent: Union["DataFileList", QtWidgets.QTreeWidgetItem] = self
         for p in pathList:
             parent = add(parent, p)
 
-    def removeItemByPath(self, path: str):
+    def removeItemByPath(self, path: str) -> None:
 
-        def remove(i):
+        def remove(i: QtWidgets.QTreeWidgetItem) -> None:
             parent = i.parent()
             if isinstance(parent, DataFileList):
                 idx = parent.indexOfTopLevelItem(i)
@@ -190,7 +200,7 @@ class DataFileList(QtWidgets.QTreeWidget):
             return
         remove(item)
 
-    def loadFromPath(self, path: str, emitNew: bool = False):
+    def loadFromPath(self, path: str, emitNew: bool = False) -> None:
         self.path = path
         files = findFilesByExtension(path, self.fileExtensions)
         newFiles = [f for f in files if f not in self.files]
@@ -207,7 +217,7 @@ class DataFileList(QtWidgets.QTreeWidget):
             self.newDataFilesFound.emit(newFiles)
 
     @Slot()
-    def processSelection(self):
+    def processSelection(self) -> None:
         selected = self.selectedItems()
         if len(selected) == 0:
             return
@@ -218,4 +228,4 @@ class DataFileList(QtWidgets.QTreeWidget):
 
 
 class MonitorToolBar(QtWidgets.QToolBar):
-    pass
\ No newline at end of file
+    pass
